@@ -2,7 +2,10 @@
 IBM Confidential
 OCO Source Materials
 (C) Copyright IBM Corporation 2019 All Rights Reserved
-The source code for this program is not published or otherwise divested of its trade secrets, irrespective of what has been deposited with the U.S. Copyright Office.
+The source code for this program is not published or otherwise divested of its trade secrets,
+irrespective of what has been deposited with the U.S. Copyright Office.
+
+Copyright (c) 2020 Red Hat, Inc.
 */
 
 package config
@@ -11,12 +14,13 @@ import (
 	"os"
 	"path/filepath"
 	"strconv"
+	"strings"
 
 	"github.com/golang/glog"
 )
 
 const (
-	AGGREGATOR_API_VERSION          = "2.1.0"
+	AGGREGATOR_API_VERSION          = "2.2.0"
 	DEFAULT_AGGREGATOR_ADDRESS      = ":3010"
 	DEFAULT_EDGE_BUILD_RATE_MS      = 15000  // 15 sec
 	DEFAULT_HTTP_TIMEOUT            = 300000 // 5 min, to fix the EOF response at the collector
@@ -24,7 +28,7 @@ const (
 	DEFAULT_REDIS_HOST              = "localhost"
 	DEFAULT_REDIS_PORT              = "6379"
 	DEFAULT_REDIS_WATCH_INTERVAL    = 15000 // 15 seconds
-	DEFAULT_REQUEST_LIMIT           = 5     // Max number of concurrent requests.
+	DEFAULT_REQUEST_LIMIT           = 10    // Max number of concurrent requests.
 	DEFAULT_SKIP_CLUSTER_VALIDATION = "false"
 )
 
@@ -79,12 +83,14 @@ func setDefault(field *string, env, defaultVal string) {
 		}
 		*field = val
 	} else if *field == "" && defaultVal != "" {
-		glog.Infof("%s not set, using default value: %s", env, defaultVal)
+		// Skip logging when running tests to reduce confusing output.
+		if !strings.HasSuffix(os.Args[0], ".test") {
+			glog.Infof("%s not set, using default value: %s", env, defaultVal)
+		}
 		*field = defaultVal
 	}
 }
 
-// TODO: Combine with function above.
 func setDefaultInt(field *int, env string, defaultVal int) {
 	if val := os.Getenv(env); val != "" {
 		glog.Infof("Using %s from environment: %s", env, val)
@@ -94,7 +100,10 @@ func setDefaultInt(field *int, env string, defaultVal int) {
 			glog.Error("Error parsing env [", env, "].  Expected an integer.  Original error: ", err)
 		}
 	} else if *field == 0 && defaultVal != 0 {
-		glog.Infof("No %s from file or environment, using default value: %d", env, defaultVal)
+		// Skip logging when running tests to reduce confusing output.
+		if !strings.HasSuffix(os.Args[0], ".test") {
+			glog.Infof("No %s from file or environment, using default value: %d", env, defaultVal)
+		}
 		*field = defaultVal
 	}
 }
