@@ -9,6 +9,8 @@ package dbconnector
 
 import (
 	"strings"
+
+	rg2 "github.com/redislabs/redisgraph-go"
 )
 
 // Merges maps, putting values of b over top of values from a. In practice this doesn't matter because the error maps are keyed by UID and don't share any keys.
@@ -50,9 +52,6 @@ func IsGraphMissing(err error) bool {
 	return strings.Contains(err.Error(), "key doesn't contains a graph object")
 }
 
-func IsPropertySet(res QueryResult) bool {
-	if len(res.Statistics) >= 1 {
-		return strings.Contains(res.Statistics[0], "Properties set") || strings.Contains(res.Statistics[0], "Update Not Required")
-	}
-	return false
+func IsPropertySet(res *rg2.QueryResult) bool {
+	return res.PropertiesSet() > 0
 }
